==> flutter_payphone-0.0.8.tar.gz: lib/flutter_payphone.dart <==
library flutter_payphone;

import 'dart:async';
import 'dart:convert';
import 'package:http/http.dart' as http;

class Payphone {
  String tokenApiKey;

  Payphone(this.tokenApiKey);

  Future<Map<String, dynamic>> solicitarVentayEsperarResultado(phoneNumber, amount, amountWithTax, tax, clientTransactionId, referencia) async {
    var respuestaSolicitudVenta = await _saleRequest(phoneNumber, amount, amountWithTax, tax, clientTransactionId, referencia);
    if(respuestaSolicitudVenta['transactionId']!=null) {
      var status = await _saleStatus(clientTransactionId);
      int statusCode = status.first['statusCode'];
      while (statusCode == 1 /* PENDIENTE */) {
        status = await _saleStatus(clientTransactionId);
        statusCode = status.first['statusCode'];
      }
      return status.first;
    }else {
      return respuestaSolicitudVenta;
    }
  }



  Future<Map<String, dynamic>> _saleRequest(
      phoneNumber, amount, amountWithTax, tax, clientTransactionId, referencia) async {
    var url = 'https://pay.payphonetodoesposible.com/api/Sale';
    var response = await http.post(
      url,
      headers: {
        'Content-Type': 'application/json',
        'Accept': 'application/json',
        'Authorization': 'Bearer '+tokenApiKey,
      },
      body: jsonEncode(<String, dynamic>{
        if (phoneNumber != null) 'phoneNumber': phoneNumber,
        'countryCode': "593",
        /* Ecuador */
        if (amount != null)
          'amount': amount,
        if (amountWithTax != null) 'amountWithTax': amountWithTax,
        if (tax != null) 'tax': tax,
        if (referencia != null ) 'referencia': referencia,
        if (clientTransactionId != null)
          'clientTransactionId': clientTransactionId,
        'optionalParameter1':
            "Transacción procesada con el plugin para flutter: flutter_payphone"
      }),
    );

    return json.decode(response.body);
  }

  Future<List<dynamic>> _saleStatus(clientTransactionId) async {
    var url = 'https://pay.payphonetodoesposible.com/api/Sale/client/' +
        clientTransactionId;
    var response = await http.get(
      url,
      headers: {
        'Accept': 'application/json',
        'Authorization': 'Bearer '+tokenApiKey,
      },
    );
    return json.decode(response.body);
  }
}

==> flutter_payphone-0.0.9.tar.gz: lib/flutter_payphone.dart <==
library flutter_payphone;

import 'dart:async';
import 'dart:convert';
import 'package:http/http.dart' as http;

class Payphone {
  String tokenApiKey;

  Payphone(this.tokenApiKey);

  Future<Map<String, dynamic>> solicitarVentayEsperarResultado(phoneNumber,
      amount, amountWithTax, tax, clientTransactionId, referencia) async {
    var respuestaSolicitudVenta = await _saleRequest(phoneNumber, amount,
        amountWithTax, tax, clientTransactionId, referencia);
    if (respuestaSolicitudVenta['transactionId'] != null) {
      List<dynamic> status = await _saleStatus(clientTransactionId);
      print("status fuera while: $status");
      int statusCode = status.first['statusCode'];
      while (statusCode == 1 /* PENDIENTE */) {
        await Future.delayed(Duration(seconds : 5));
        status = await _saleStatus(clientTransactionId);
        print("status dentro while: $status");
        statusCode = status.first['statusCode'];
      }
      return status.first;
    } else {
      return respuestaSolicitudVenta;
    }
  }

  Future<Map<String, dynamic>> _saleRequest(phoneNumber, amount, amountWithTax,
      tax, clientTransactionId, referencia) async {
    var url = 'https://pay.payphonetodoesposible.com/api/Sale';
    var response = await http.post(
      url,
      headers: {
        'Content-Type': 'application/json',
        'Accept': 'application/json',
        'Authorization': 'Bearer ' + tokenApiKey,
      },
      body: jsonEncode(<String, dynamic>{
        if (phoneNumber != null) 'phoneNumber': phoneNumber,
        'countryCode': "593",
        /* Ecuador */
        if (amount != null)
          'amount': amount,
        if (amountWithTax != null) 'amountWithTax': amountWithTax,
        if (tax != null) 'tax': tax,
        if (referencia != null) 'referencia': referencia,
        if (clientTransactionId != null)
          'clientTransactionId': clientTransactionId,
        'optionalParameter1':
            "Transacción procesada con el plugin para flutter: flutter_payphone"
      }),
    );

    return json.decode(response.body);
  }

  Future<List<dynamic>> _saleStatus(clientTransactionId) async {
    var url = 'https://pay.payphonetodoesposible.com/api/Sale/client/' +
        clientTransactionId;
    var response = await http.get(
      url,
      headers: {
        'Accept': 'application/json',
        'Authorization': 'Bearer ' + tokenApiKey,
      },
    );
    return json.decode(response.body);
  }
}
